char_code(x)
code_char(x)
endp(x)
eql(x,y)
equal(x,y)
equalp(x,y)
fix(x)
lf(x)
make_fixnum(x)
CMPmake_fixnum(x)
small_fixnum(x)
type_of(x)
STREF(a,b,c)
STSET(a,b,c,val)
immnum_bool(a,b,c)
immnum_ior(x,y)
immnum_and(x,y)
immnum_xor(x,y)
immnum_not(x)
immnum_nand(x,y)
immnum_nor(x,y)
immnum_eqv(x,y)
immnum_andc1(x,y)
immnum_andc2(x,y)
immnum_orc1(x,y)
immnum_orc2(x,y)
tp0(x)
tp1(x)
tp2(x)
tp3(x)
tp4(x)
tp5(x)
tp6(x)
tp7(x)
tp8(x)
sf(x)
lf(x)
sfc(x)
lfc(x)
eql_is_eq(x)
equal_is_eq(x)
equalp_is_eq(x)
listp(x)
functionp(x)
rationalp(x)
atom(x)
numberp(x)
realp(x)
consp(x)
integerp(x)
rationalp(x)
floatp(x)
realp(x)
numberp(x)
vectorp(x)
arrayp(x)
compiled_functionp(x)
pathname_designatorp(x)
OBJNULL
Cnil
Ct
bds_check
bds_unwind1
bds_bind(a,b)
va_arg(a,b)
va_start(a,b)
va_end(a)
ON_STACK_CONS(x,y)
frs_pop()
frs_push(a,b)
vs_push(x)
vs_reserve(x)
vs_head
vs_pop
vs_check
ihs_check
alloc_frame_id()
complex
I
NOT_SPECIAL
VOL
mpz_even_p(x)
mpz_odd_p(x)
mpz_sgn(x)
NULL
FALSE
FEerror(a,b,c)
TRUE
MULTIPLE_VALUES_LIMIT
is_imm_fixnum(x)
is_imm_fix(x)
aref1
OBJ_ALIGNED_STACK_ALLOC(x)
NO_RETURN
